@@ -9,7 +9,6 @@ describe 'keystone::db' do
         :db_max_retries          => '<SERVICE DEFAULT>',
         :connection              => 'sqlite:////var/lib/keystone/keystone.sqlite',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
@@ -24,7 +23,6 @@ describe 'keystone::db' do
           :database_db_max_retries          => '-1',
           :database_connection              => 'mysql+pymysql://keystone:keystone@localhost/keystone',
           :database_connection_recycle_time => '3601',
-          :database_min_pool_size           => '2',
           :database_max_pool_size           => '21',
           :database_max_retries             => '11',
           :database_max_overflow            => '21',
@@ -39,7 +37,6 @@ describe 'keystone::db' do
         :db_max_retries          => '-1',
         :connection              => 'mysql+pymysql://keystone:keystone@localhost/keystone',
         :connection_recycle_time => '3601',
-        :min_pool_size           => '2',
         :max_pool_size           => '21',
         :max_retries             => '11',
         :retry_interval          => '11',
