@@ -37,40 +37,10 @@ describe 'keystone::ldap_backend' do
           :user_enabled_invert                  => 'False',
           :user_attribute_ignore                => '',
           :user_default_project_id_attribute    => 'defaultProject',
-          :user_allow_create                    => 'False',
-          :user_allow_update                    => 'False',
-          :user_allow_delete                    => 'False',
           :user_pass_attribute                  => 'krbPassword',
           :user_enabled_emulation               => 'True',
           :user_enabled_emulation_dn            => 'cn=openstack-enabled,cn=groups,cn=accounts,dc=example,dc=com',
           :user_additional_attribute_mapping    => 'description:name, gecos:name',
-          :project_tree_dn                      => 'ou=projects,ou=openstack,dc=example,dc=com',
-          :project_filter                       => '',
-          :project_objectclass                  => 'organizationalUnit',
-          :project_id_attribute                 => 'ou',
-          :project_member_attribute             => 'member',
-          :project_desc_attribute               => 'description',
-          :project_name_attribute               => 'ou',
-          :project_enabled_attribute            => 'enabled',
-          :project_domain_id_attribute          => 'businessCategory',
-          :project_attribute_ignore             => '',
-          :project_allow_create                 => 'True',
-          :project_allow_update                 => 'True',
-          :project_allow_delete                 => 'True',
-          :project_enabled_emulation            => 'False',
-          :project_enabled_emulation_dn         => 'True',
-          :project_additional_attribute_mapping => 'cn=enabled,ou=openstack,dc=example,dc=com',
-          :role_tree_dn                         => 'ou=roles,ou=openstack,dc=example,dc=com',
-          :role_filter                          => '',
-          :role_objectclass                     => 'organizationalRole',
-          :role_id_attribute                    => 'cn',
-          :role_name_attribute                  => 'ou',
-          :role_member_attribute                => 'roleOccupant',
-          :role_attribute_ignore                => 'description',
-          :role_allow_create                    => 'True',
-          :role_allow_update                    => 'True',
-          :role_allow_delete                    => 'True',
-          :role_additional_attribute_mapping    => '',
           :group_tree_dn                        => 'ou=groups,ou=openstack,dc=example,dc=com',
           :group_filter                         => 'cn=enabled-groups,cn=groups,cn=accounts,dc=example,dc=com',
           :group_objectclass                    => 'organizationalRole',
@@ -80,9 +50,6 @@ describe 'keystone::ldap_backend' do
           :group_members_are_ids                => 'True',
           :group_desc_attribute                 => 'description',
           :group_attribute_ignore               => '',
-          :group_allow_create                   => 'False',
-          :group_allow_update                   => 'False',
-          :group_allow_delete                   => 'False',
           :group_additional_attribute_mapping   => '',
           :group_ad_nesting                     => 'True',
           :chase_referrals                      => 'False',
@@ -127,45 +94,11 @@ describe 'keystone::ldap_backend' do
         is_expected.to contain_keystone_domain_config('Default::ldap/user_attribute_ignore').with_value('')
         is_expected.to contain_keystone_domain_config('Default::ldap/user_default_project_id_attribute').with_value('defaultProject')
         is_expected.to contain_keystone_domain_config('Default::ldap/user_tree_dn').with_value('cn=users,dc=example,dc=com')
-        is_expected.to contain_keystone_domain_config('Default::ldap/user_allow_create').with_value('False')
-        is_expected.to contain_keystone_domain_config('Default::ldap/user_allow_update').with_value('False')
-        is_expected.to contain_keystone_domain_config('Default::ldap/user_allow_delete').with_value('False')
         is_expected.to contain_keystone_domain_config('Default::ldap/user_pass_attribute').with_value('krbPassword')
         is_expected.to contain_keystone_domain_config('Default::ldap/user_enabled_emulation').with_value('True')
         is_expected.to contain_keystone_domain_config('Default::ldap/user_enabled_emulation_dn').with_value('cn=openstack-enabled,cn=groups,cn=accounts,dc=example,dc=com')
         is_expected.to contain_keystone_domain_config('Default::ldap/user_additional_attribute_mapping').with_value('description:name, gecos:name')
 
-        # projects
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_tree_dn').with_value('ou=projects,ou=openstack,dc=example,dc=com')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_filter').with_value('')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_objectclass').with_value('organizationalUnit')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_id_attribute').with_value('ou')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_member_attribute').with_value('member')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_desc_attribute').with_value('description')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_name_attribute').with_value('ou')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_enabled_attribute').with_value('enabled')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_domain_id_attribute').with_value('businessCategory')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_attribute_ignore').with_value('')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_allow_create').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_allow_update').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_allow_delete').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_enabled_emulation').with_value('False')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_enabled_emulation_dn').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/project_additional_attribute_mapping').with_value('cn=enabled,ou=openstack,dc=example,dc=com')
-
-        # roles
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_tree_dn').with_value('ou=roles,ou=openstack,dc=example,dc=com')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_filter').with_value('')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_objectclass').with_value('organizationalRole')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_id_attribute').with_value('cn')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_name_attribute').with_value('ou')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_member_attribute').with_value('roleOccupant')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_attribute_ignore').with_value('description')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_allow_create').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_allow_update').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_allow_delete').with_value('True')
-        is_expected.to contain_keystone_domain_config('Default::ldap/role_additional_attribute_mapping').with_value('')
-
         # groups
         is_expected.to contain_keystone_domain_config('Default::ldap/group_tree_dn').with_value('ou=groups,ou=openstack,dc=example,dc=com')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_filter').with_value('cn=enabled-groups,cn=groups,cn=accounts,dc=example,dc=com')
@@ -176,9 +109,6 @@ describe 'keystone::ldap_backend' do
         is_expected.to contain_keystone_domain_config('Default::ldap/group_desc_attribute').with_value('description')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_name_attribute').with_value('cn')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_attribute_ignore').with_value('')
-        is_expected.to contain_keystone_domain_config('Default::ldap/group_allow_create').with_value('False')
-        is_expected.to contain_keystone_domain_config('Default::ldap/group_allow_update').with_value('False')
-        is_expected.to contain_keystone_domain_config('Default::ldap/group_allow_delete').with_value('False')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_additional_attribute_mapping').with_value('')
         is_expected.to contain_keystone_domain_config('Default::ldap/group_ad_nesting').with_value('True')
 
